Requirement

Struct Requirement 

pub struct Requirement {
    pub name: String,
    pub range: Option<Ranges<RerVersion>>,
    /* private fields */
}
Requirement

Description

A requirement is the representation of the scope of range of a specific package. Mainly it is use to represent a requierement in the list of requieres of a package.

Fields

name: Stringrange: Option<Ranges<RerVersion>>

Implementations

Source

impl Requirement

pub fn get_pubgrub(&self) -> (String, Ranges<RerVersion>)

get_pubgrub
Description

Get the name and the range of the requirement in the pubgrub format. Use mainly to add a dependency in the pubgrub solver.

pub fn get_name(&self) -> &str

get_name
Description

Get the name of the requirement.

Example
use rer_version::Requirement;
let a = Requirement::from("maya-1.2.3+<2.0.0");
assert_eq!(a.get_name(), "maya");
pub fn get_version_range(&self) -> Option<Ranges<RerVersion>>

get_version_range
Description

Get the range of the requirement.

pub fn merge(&self, other: &Self) -> Option<Self>

merge
Description

Merge two requirements into one. If the requirements are not compatible, return None.

pub fn is_weak_ref(&self) -> bool

is_weak_ref
Description

Check if the requirement is a weak reference.